==> ejc-probid-api-3.0.0-20220715.084523-9-sources.jar: com/ejianc/business/pay/vo/PayVO.java <==
package com.ejianc.business.pay.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 保证金缴纳实体
 *
 * @author generator
 */
public class PayVO extends BaseVO {
	private static final long serialVersionUID = -3170922581364588700L;

	private Long employeeId; // 经办人id
	private String employeeName; // 经办人名称
	private Date commitDate; // 提交日期
	private String commitUserName; // 提交人名称
	private String commitUserCode; // 提交人账号
	private Date effectiveDate; // 生效日期
	private String billCode; // 单据编码
	private String billName; // 单据名称
	private String billType; // 单据类型
	private Integer billState; // 单据状态
	private String billStateName; // 单据状态名称
	private Long projectId; // 项目id
	private String projectCode; // 项目编码
	private String projectName; // 项目名称
	private String constructionUnit; // 建设单位
	private Date registrationDeadline; // 报名截止日期
	private Date bidOpenDate; // 开标日期
	private Long bidUnitId; // 投标单位id
	private String bidUnitCode; // 投标单位编码
	private String bidUnitName; // 投标单位名称
	private String bondMode; // 保证金形式 0-现金、1-保函
	private String memo; // 说明
	private Date assureStartDate; // 担保开始日期
	private Date assureEndDate; // 担保结束日期
	private BigDecimal backletterMny; // 保函金额
	private BigDecimal assureMny; // 其中要求担保金额
	private String managingBankName; // 经办银行
	private BigDecimal backletterServiceFee; // 保函手续费
	private BigDecimal payMny; // 缴纳金额
	private BigDecimal backMny; // 退还金额
	private BigDecimal remainMny; // 剩余金额

	private List<PayBackRecordVO> payBackRecordList = new ArrayList<>(); // 保证金缴纳-退还记录实体

	public Long getEmployeeId() {
		return employeeId;
	}

	public void setEmployeeId(Long employeeId) {
		this.employeeId = employeeId;
	}

	public String getEmployeeName() {
		return employeeName;
	}

	public void setEmployeeName(String employeeName) {
		this.employeeName = employeeName;
	}

	public Date getCommitDate() {
		return commitDate;
	}

	public void setCommitDate(Date commitDate) {
		this.commitDate = commitDate;
	}

	public String getCommitUserName() {
		return commitUserName;
	}

	public void setCommitUserName(String commitUserName) {
		this.commitUserName = commitUserName;
	}

	public String getCommitUserCode() {
		return commitUserCode;
	}

	public void setCommitUserCode(String commitUserCode) {
		this.commitUserCode = commitUserCode;
	}

	public Date getEffectiveDate() {
		return effectiveDate;
	}

	public void setEffectiveDate(Date effectiveDate) {
		this.effectiveDate = effectiveDate;
	}

	public String getBillCode() {
		return billCode;
	}

	public void setBillCode(String billCode) {
		this.billCode = billCode;
	}

	public String getBillName() {
		return billName;
	}

	public void setBillName(String billName) {
		this.billName = billName;
	}

	public String getBillType() {
		return billType;
	}

	public void setBillType(String billType) {
		this.billType = billType;
	}

	public Integer getBillState() {
		return billState;
	}

	public void setBillState(Integer billState) {
		this.billState = billState;
	}

	public String getBillStateName() {
		return billStateName;
	}

	public void setBillStateName(String billStateName) {
		this.billStateName = billStateName;
	}

	public Long getProjectId() {
		return projectId;
	}

	public void setProjectId(Long projectId) {
		this.projectId = projectId;
	}

	public String getProjectCode() {
		return projectCode;
	}

	public void setProjectCode(String projectCode) {
		this.projectCode = projectCode;
	}

	public String getProjectName() {
		return projectName;
	}

	public void setProjectName(String projectName) {
		this.projectName = projectName;
	}

	public String getConstructionUnit() {
		return constructionUnit;
	}

	public void setConstructionUnit(String constructionUnit) {
		this.constructionUnit = constructionUnit;
	}

	public Date getRegistrationDeadline() {
		return registrationDeadline;
	}

	public void setRegistrationDeadline(Date registrationDeadline) {
		this.registrationDeadline = registrationDeadline;
	}

	public Date getBidOpenDate() {
		return bidOpenDate;
	}

	public void setBidOpenDate(Date bidOpenDate) {
		this.bidOpenDate = bidOpenDate;
	}

	public Long getBidUnitId() {
		return bidUnitId;
	}

	public void setBidUnitId(Long bidUnitId) {
		this.bidUnitId = bidUnitId;
	}

	public String getBidUnitCode() {
		return bidUnitCode;
	}

	public void setBidUnitCode(String bidUnitCode) {
		this.bidUnitCode = bidUnitCode;
	}

	public String getBidUnitName() {
		return bidUnitName;
	}

	public void setBidUnitName(String bidUnitName) {
		this.bidUnitName = bidUnitName;
	}

	public String getBondMode() {
		return bondMode;
	}

	public void setBondMode(String bondMode) {
		this.bondMode = bondMode;
	}

	public String getMemo() {
		return memo;
	}

	public void setMemo(String memo) {
		this.memo = memo;
	}

	public Date getAssureStartDate() {
		return assureStartDate;
	}

	public void setAssureStartDate(Date assureStartDate) {
		this.assureStartDate = assureStartDate;
	}

	public Date getAssureEndDate() {
		return assureEndDate;
	}

	public void setAssureEndDate(Date assureEndDate) {
		this.assureEndDate = assureEndDate;
	}

	public BigDecimal getBackletterMny() {
		return backletterMny;
	}

	public void setBackletterMny(BigDecimal backletterMny) {
		this.backletterMny = backletterMny;
	}

	public BigDecimal getAssureMny() {
		return assureMny;
	}

	public void setAssureMny(BigDecimal assureMny) {
		this.assureMny = assureMny;
	}

	public String getManagingBankName() {
		return managingBankName;
	}

	public void setManagingBankName(String managingBankName) {
		this.managingBankName = managingBankName;
	}

	public BigDecimal getBackletterServiceFee() {
		return backletterServiceFee;
	}

	public void setBackletterServiceFee(BigDecimal backletterServiceFee) {
		this.backletterServiceFee = backletterServiceFee;
	}

	public BigDecimal getPayMny() {
		return payMny;
	}

	public void setPayMny(BigDecimal payMny) {
		this.payMny = payMny;
	}

	public BigDecimal getBackMny() {
		return backMny;
	}

	public void setBackMny(BigDecimal backMny) {
		this.backMny = backMny;
	}

	public BigDecimal getRemainMny() {
		return remainMny;
	}

	public void setRemainMny(BigDecimal remainMny) {
		this.remainMny = remainMny;
	}

	public List<PayBackRecordVO> getPayBackRecordList() {
		return payBackRecordList;
	}

	public void setPayBackRecordList(List<PayBackRecordVO> payBackRecordList) {
		this.payBackRecordList = payBackRecordList;
	}
}

==> ejc-probid-api-3.0.0-20220829.095911-80-sources.jar: com/ejianc/business/pay/vo/PayVO.java <==
package com.ejianc.business.pay.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 保证金缴纳实体
 *
 * @author generator
 */
public class PayVO extends BaseVO {
	private static final long serialVersionUID = -3170922581364588700L;

	private Long employeeId; // 经办人id
	private String employeeName; // 经办人名称
	private Date commitDate; // 提交日期
	private String commitUserName; // 提交人名称
	private String commitUserCode; // 提交人账号
	private Date effectiveDate; // 生效日期
	private String billCode; // 单据编码
	private String billName; // 单据名称
	private String billType; // 单据类型
	private Integer billState; // 单据状态
	private String billStateName; // 单据状态名称
	private Long projectId; // 项目id
	private String projectCode; // 项目编码
	private String projectName; // 项目名称
	private String constructionUnit; // 建设单位
	@JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
	private Date registrationDeadline; // 报名截止日期
	@JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
	private Date bidOpenDate; // 开标日期
	private Long bidUnitId; // 投标单位id
	private String bidUnitCode; // 投标单位编码
	private String bidUnitName; // 投标单位名称
	private String bondMode; // 保证金形式 0-现金、1-保函
	private String bondModeName; // 保证金形式名称
	private String memo; // 说明
	@JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
	private Date assureStartDate; // 担保开始日期
	@JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
	private Date assureEndDate; // 担保结束日期
	private BigDecimal backletterMny; // 保函金额
	private BigDecimal assureMny; // 其中要求担保金额
	private String managingBankName; // 经办银行
	private BigDecimal backletterServiceFee; // 保函手续费
	private BigDecimal payMny; // 缴纳金额
	private BigDecimal backMny; // 退还金额
	private BigDecimal remainMny; // 剩余金额

	private List<PayBackRecordVO> payBackRecordList = new ArrayList<>(); // 保证金缴纳-退还记录实体

	public Long getEmployeeId() {
		return employeeId;
	}

	@ReferDeserialTransfer
	public void setEmployeeId(Long employeeId) {
		this.employeeId = employeeId;
	}

	public String getEmployeeName() {
		return employeeName;
	}

	public void setEmployeeName(String employeeName) {
		this.employeeName = employeeName;
	}

	public Date getCommitDate() {
		return commitDate;
	}

	public void setCommitDate(Date commitDate) {
		this.commitDate = commitDate;
	}

	public String getCommitUserName() {
		return commitUserName;
	}

	public void setCommitUserName(String commitUserName) {
		this.commitUserName = commitUserName;
	}

	public String getCommitUserCode() {
		return commitUserCode;
	}

	public void setCommitUserCode(String commitUserCode) {
		this.commitUserCode = commitUserCode;
	}

	public Date getEffectiveDate() {
		return effectiveDate;
	}

	public void setEffectiveDate(Date effectiveDate) {
		this.effectiveDate = effectiveDate;
	}

	public String getBillCode() {
		return billCode;
	}

	public void setBillCode(String billCode) {
		this.billCode = billCode;
	}

	public String getBillName() {
		return billName;
	}

	public void setBillName(String billName) {
		this.billName = billName;
	}

	public String getBillType() {
		return billType;
	}

	public void setBillType(String billType) {
		this.billType = billType;
	}

	public Integer getBillState() {
		return billState;
	}

	public void setBillState(Integer billState) {
		this.billState = billState;
	}

	public String getBillStateName() {
		return billStateName;
	}

	public void setBillStateName(String billStateName) {
		this.billStateName = billStateName;
	}

	public Long getProjectId() {
		return projectId;
	}

	@ReferDeserialTransfer
	public void setProjectId(Long projectId) {
		this.projectId = projectId;
	}

	public String getProjectCode() {
		return projectCode;
	}

	public void setProjectCode(String projectCode) {
		this.projectCode = projectCode;
	}

	public String getProjectName() {
		return projectName;
	}

	public void setProjectName(String projectName) {
		this.projectName = projectName;
	}

	public String getConstructionUnit() {
		return constructionUnit;
	}

	public void setConstructionUnit(String constructionUnit) {
		this.constructionUnit = constructionUnit;
	}

	public Date getRegistrationDeadline() {
		return registrationDeadline;
	}

	public void setRegistrationDeadline(Date registrationDeadline) {
		this.registrationDeadline = registrationDeadline;
	}

	public Date getBidOpenDate() {
		return bidOpenDate;
	}

	public void setBidOpenDate(Date bidOpenDate) {
		this.bidOpenDate = bidOpenDate;
	}

	public Long getBidUnitId() {
		return bidUnitId;
	}

	public void setBidUnitId(Long bidUnitId) {
		this.bidUnitId = bidUnitId;
	}

	public String getBidUnitCode() {
		return bidUnitCode;
	}

	public void setBidUnitCode(String bidUnitCode) {
		this.bidUnitCode = bidUnitCode;
	}

	public String getBidUnitName() {
		return bidUnitName;
	}

	public void setBidUnitName(String bidUnitName) {
		this.bidUnitName = bidUnitName;
	}

	public String getBondMode() {
		return bondMode;
	}

	public void setBondMode(String bondMode) {
		this.bondMode = bondMode;
	}

	public String getBondModeName() {
		return bondModeName;
	}

	public void setBondModeName(String bondModeName) {
		this.bondModeName = bondModeName;
	}

	public String getMemo() {
		return memo;
	}

	public void setMemo(String memo) {
		this.memo = memo;
	}

	public Date getAssureStartDate() {
		return assureStartDate;
	}

	public void setAssureStartDate(Date assureStartDate) {
		this.assureStartDate = assureStartDate;
	}

	public Date getAssureEndDate() {
		return assureEndDate;
	}

	public void setAssureEndDate(Date assureEndDate) {
		this.assureEndDate = assureEndDate;
	}

	public BigDecimal getBackletterMny() {
		return backletterMny;
	}

	public void setBackletterMny(BigDecimal backletterMny) {
		this.backletterMny = backletterMny;
	}

	public BigDecimal getAssureMny() {
		return assureMny;
	}

	public void setAssureMny(BigDecimal assureMny) {
		this.assureMny = assureMny;
	}

	public String getManagingBankName() {
		return managingBankName;
	}

	public void setManagingBankName(String managingBankName) {
		this.managingBankName = managingBankName;
	}

	public BigDecimal getBackletterServiceFee() {
		return backletterServiceFee;
	}

	public void setBackletterServiceFee(BigDecimal backletterServiceFee) {
		this.backletterServiceFee = backletterServiceFee;
	}

	public BigDecimal getPayMny() {
		return payMny;
	}

	public void setPayMny(BigDecimal payMny) {
		this.payMny = payMny;
	}

	public BigDecimal getBackMny() {
		return backMny;
	}

	public void setBackMny(BigDecimal backMny) {
		this.backMny = backMny;
	}

	public BigDecimal getRemainMny() {
		return remainMny;
	}

	public void setRemainMny(BigDecimal remainMny) {
		this.remainMny = remainMny;
	}

	public List<PayBackRecordVO> getPayBackRecordList() {
		return payBackRecordList;
	}

	public void setPayBackRecordList(List<PayBackRecordVO> payBackRecordList) {
		this.payBackRecordList = payBackRecordList;
	}
}
